.. _glossary:

Glossary
========

.. glossary::
   :sorted:

   Mako
      A `templating system written by Mike Bayer
      <http://www.makotemplates.org/>`_.

   Pyramid
      A `web framework <http://pylonsproject.org/pyramid>`_.

   Configurator
      `pyramid.config.Configurator
      <http://docs.pylonsproject.org/projects/pyramid/en/latest/api/config.html#pyramid.config.Configurator>`_

   pyramid_mako
      A set of bindings that make templates written for the :term:`Mako`
      templating system work under the :term:`Pyramid` web framework.

   asset specification
       A string representing the path to a directory or file present in a
       Python module.  See `Understanding Asset Specifications
       <http://docs.pylonsproject.org/projects/pyramid/en/latest/narr/assets.html#understanding-asset-specifications>`_
       in the Pyramid documentation for more information.
